@@ -1,20 +1,20 @@
-import os
 import inspect
-
+import time
 from collections import OrderedDict
 from importlib.machinery import SourceFileLoader
-from time import time
+from pathlib import Path
 from random import randint
+from types import FunctionType
 
 from py3status.composite import Composite
 from py3status.constants import MARKUP_LANGUAGES, ON_ERROR_VALUES, POSITIONS
-from py3status.py3 import Py3, ModuleErrorException
-from py3status.profiling import profile
 from py3status.formatter import Formatter
+from py3status.profiling import profile
+from py3status.py3 import ModuleErrorException, Py3
 
 
 def make_quotes(options):
-    x = ["`{}`".format(x) for x in options]
+    x = [f"`{x}`" for x in options]
     if len(x) > 2:
         x = [", ".join(x[:-1]), x[-1]]
     return " or ".join(x)
@@ -87,7 +87,7 @@ class Module:
             ]
             self.error_output(self.error_messages[0])
             # log the error
-            msg = "Module `{}` could not be loaded".format(self.module_full_name)
+            msg = f"Module `{self.module_full_name}` could not be loaded ({e})"
             if isinstance(e, SyntaxError):
                 # provide full traceback
                 self._py3_wrapper.report_exception(msg, notify_user=False)
@@ -102,7 +102,7 @@ class Module:
             self.set_module_options(module)
 
     def __repr__(self):
-        return "<Module {}>".format(self.module_full_name)
+        return f"<Module {self.module_full_name}>"
 
     @classmethod
     def load_from_file(cls, filepath):
@@ -110,9 +110,8 @@ class Module:
         Return user-written class object from given path.
         """
         class_inst = None
-        module_name, file_ext = os.path.splitext(os.path.split(filepath)[-1])
-        if file_ext.lower() == ".py":
-            py_mod = SourceFileLoader(module_name, filepath).load_module()
+        if filepath.suffix == ".py":
+            py_mod = SourceFileLoader(filepath.stem, filepath.as_posix()).load_module()
             if hasattr(py_mod, cls.EXPECTED_CLASS):
                 class_inst = py_mod.Py3status()
         return class_inst
@@ -123,7 +122,7 @@ class Module:
         Load a py3status bundled module.
         """
         class_inst = None
-        name = "py3status.modules.{}".format(module_name)
+        name = f"py3status.modules.{module_name}"
         py_mod = __import__(name)
         components = name.split(".")
         for comp in components[1:]:
@@ -150,14 +149,12 @@ class Module:
 
                 self.error_messages = [
                     self.module_nice_name,
-                    "{}: {}".format(
-                        self.module_nice_name, str(e) or e.__class__.__name__
-                    ),
+                    f"{e}",
                 ]
-                self.runtime_error(self.error_messages[0], "post_config_hook")
-                msg = "Exception in `%s` post_config_hook()" % self.module_full_name
+                self.runtime_error(self.error_messages[1], "post_config_hook")
+                msg = f"Exception in `{self.module_full_name}` post_config_hook() : {self.error_messages}"
                 self._py3_wrapper.report_exception(msg, notify_user=False)
-                self._py3_wrapper.log("terminating module %s" % self.module_full_name)
+                self._py3_wrapper.log(f"terminating module {self.module_full_name}")
         self.enabled = True
 
     def runtime_error(self, msg, method):
@@ -175,7 +172,7 @@ class Module:
         # only show first line of error
         msg = msg.splitlines()[0]
 
-        errors = [self.module_nice_name, "{}: {}".format(self.module_nice_name, msg)]
+        errors = [self.module_nice_name, f"{self.module_nice_name}[{method}]: {msg}"]
 
         # if we have shown this error then keep in the same state
         if self.error_messages != errors:
@@ -202,7 +199,11 @@ class Module:
             "name": self.module_name,
         }
         for method in self.methods.values():
-            if method_affected and method["method"] != method_affected:
+            if (
+                method_affected
+                and method["method"] != method_affected
+                and method_affected != "post_config_hook"
+            ):
                 continue
 
             method["last_output"] = [error]
@@ -228,7 +229,7 @@ class Module:
         self.prepare_module()
         if not (self.disabled or self.terminated):
             # Start the module and call its output method(s)
-            self._py3_wrapper.log("starting module %s" % self.module_full_name)
+            self._py3_wrapper.log(f"starting module {self.module_full_name}")
             self._py3_wrapper.timeout_queue_add(self)
 
     def force_update(self):
@@ -238,10 +239,10 @@ class Module:
         if self.disabled or self.terminated or not self.enabled:
             return
         # clear cached_until for each method to allow update
-        for meth in self.methods:
-            self.methods[meth]["cached_until"] = time()
+        for meth, my_method in self.methods.items():
+            my_method["cached_until"] = time.monotonic()
             if self.config["debug"]:
-                self._py3_wrapper.log("clearing cache for method {}".format(meth))
+                self._py3_wrapper.log(f"clearing cache for method {meth}")
         # set module to update
         self._py3_wrapper.timeout_queue_add(self)
 
@@ -254,7 +255,7 @@ class Module:
         # purge from any container modules
         self._py3_wrapper.purge_module(self.module_full_name)
         self.error_output("")
-        self._py3_wrapper.log("disabling module `%s`" % self.module_full_name)
+        self._py3_wrapper.log(f"disabling module `{self.module_full_name}`")
 
     def wake(self):
         self.sleeping = False
@@ -323,7 +324,7 @@ class Module:
         if not hasattr(min_width, "none_setting"):
             if not isinstance(min_width, int):
                 err = "Invalid `min_width` attribute, should be an int. "
-                err += "Got `{}`.".format(min_width)
+                err += f"Got `{min_width}`."
                 raise TypeError(err)
             self.i3bar_module_options["min_width"] = min_width
 
@@ -332,24 +333,30 @@ class Module:
                 if align not in POSITIONS:
                     err = "Invalid `align` attribute, should be "
                     err += make_quotes(POSITIONS)
-                    err += ". Got `{}`.".format(align)
+                    err += f". Got `{align}`."
                     raise ValueError(err)
                 self.i3bar_module_options["align"] = align
 
         separator = fn(self.module_full_name, "separator")
         if not hasattr(separator, "none_setting"):
-            if not isinstance(separator, bool):
-                err = "Invalid `separator` attribute, should be a boolean. "
-                err += "Got `{}`.".format(separator)
-                raise TypeError(err)
-            self.i3bar_module_options["separator"] = separator
+            # HACK: separator is a valid setting in the general section
+            # of the configuration. but it's a string, not a boolean.
+            # revisit how i3status and py3status differ in this regard.
+            # if not isinstance(separator, bool):
+
+            #     err = "Invalid `separator` attribute, should be a boolean. "
+            #     err += f"Got `{separator}`."
+            #     raise TypeError(err)
+            # self.i3bar_module_options["separator"] = separator
+            if isinstance(separator, bool):
+                self.i3bar_module_options["separator"] = separator
 
         separator_block_width = fn(self.module_full_name, "separator_block_width")
         if not hasattr(separator_block_width, "none_setting"):
             if not isinstance(separator_block_width, int):
                 err = "Invalid `separator_block_width` attribute, "
                 err += "should be an int. "
-                err += "Got `{}`.".format(separator_block_width)
+                err += f"Got `{separator_block_width}`."
                 raise TypeError(err)
             self.i3bar_module_options["separator_block_width"] = separator_block_width
 
@@ -359,7 +366,7 @@ class Module:
             color = self.module_class.py3._get_color(background)
             if not color:
                 err = "Invalid `background` attribute should be a color. "
-                err += "Got `{}`.".format(background)
+                err += f"Got `{background}`."
                 raise ValueError(err)
             self.i3bar_gaps_module_options["background"] = color
 
@@ -368,7 +375,7 @@ class Module:
             color = self.module_class.py3._get_color(border)
             if not color:
                 err = "Invalid `border` attribute, should be a color. "
-                err += "Got `{}`.".format(border)
+                err += f"Got `{border}`."
                 raise ValueError(err)
             self.i3bar_gaps_module_options["border"] = color
 
@@ -378,9 +385,9 @@ class Module:
                 if hasattr(param, "none_setting"):
                     param = 1
                 elif not isinstance(param, int):
-                    err = "Invalid `{}` attribute, ".format(name)
+                    err = f"Invalid `{name}` attribute, "
                     err += "should be an int. "
-                    err += "Got `{}`.".format(param)
+                    err += f"Got `{param}`."
                     raise TypeError(err)
                 self.i3bar_gaps_module_options[name] = param
 
@@ -389,7 +396,7 @@ class Module:
         if not hasattr(min_length, "none_setting"):
             if not isinstance(min_length, int):
                 err = "Invalid `min_length` attribute, should be an int. "
-                err += "Got `{}`.".format(min_length)
+                err += f"Got `{min_length}`."
                 raise TypeError(err)
             self.py3status_module_options["min_length"] = min_length
             self.random_int = randint(0, 1)
@@ -399,7 +406,7 @@ class Module:
                 if position not in POSITIONS:
                     err = "Invalid `position` attribute, should be "
                     err += make_quotes(POSITIONS)
-                    err += ". Got `{}`.".format(position)
+                    err += f". Got `{position}`."
                     raise ValueError(err)
                 self.py3status_module_options["position"] = position
 
@@ -409,7 +416,7 @@ class Module:
             if markup not in MARKUP_LANGUAGES:
                 err = "Invalid `markup` attribute, should be "
                 err += make_quotes(MARKUP_LANGUAGES)
-                err += ". Got `{}`.".format(markup)
+                err += f". Got `{markup}`."
                 raise ValueError(err)
             self.i3bar_module_options["markup"] = markup
             self.py3status_module_options["markup"] = markup
@@ -459,7 +466,7 @@ class Module:
             # make sure all components have a name
             if "name" not in item:
                 instance_index = item.get("index", index)
-                item["instance"] = "{} {}".format(self.module_inst, instance_index)
+                item["instance"] = f"{self.module_inst} {instance_index}"
                 item["name"] = self.module_name
             # hide separator for all inner components unless existing
             if index != composite_length:
@@ -513,13 +520,13 @@ class Module:
             min_length = self.py3status_module_options["min_length"]
 
             # get length, skip if length exceeds min_length
-            length = sum([len(x["full_text"]) for x in response["composite"]])
+            length = sum(len(x["full_text"]) for x in response["composite"])
             if length >= min_length:
                 return
 
             # sometimes we go under min_length to pad both side evenly,
             # we will add extra space on either side to honor min_length
-            padding = int((min_length / 2.0) - (length / 2.0))
+            padding = min_length // 2 - length // 2
             offset = min_length - ((padding * 2) + length)
 
             # set position
@@ -537,9 +544,7 @@ class Module:
 
             # padding
             if left:
-                response["composite"][0]["full_text"] = (
-                    left + response["composite"][0]["full_text"]
-                )
+                response["composite"][0]["full_text"] = left + response["composite"][0]["full_text"]
             if right:
                 response["composite"][-1]["full_text"] += right
 
@@ -588,23 +593,18 @@ class Module:
             # user provided modules take precedence over py3status provided modules
             if self.module_name in user_modules:
                 include_path, f_name = user_modules[self.module_name]
-                module_path = os.path.join(include_path, f_name)
-                self._py3_wrapper.log(
-                    'loading module "{}" from {}'.format(module, module_path)
-                )
+                module_path = Path(include_path) / f_name
+                self._py3_wrapper.log(f'loading module "{module}" from {module_path}')
                 self.module_class = self.load_from_file(module_path)
             # load from py3status provided modules
             else:
                 self._py3_wrapper.log(
-                    'loading module "{}" from py3status.modules.{}'.format(
-                        module, self.module_name
-                    )
+                    'loading module "{}" from py3status.modules.{}'.format(module, self.module_name)
                 )
                 self.module_class = self.load_from_namespace(self.module_name)
 
         class_inst = self.module_class
         if class_inst:
-
             try:
                 # containers have items attribute set to a list of contained
                 # module instance names.  If there are no contained items then
@@ -661,10 +661,8 @@ class Module:
                         msg = item["msg"]
                         param = item.get("param")
                         if param:
-                            msg = "`{}` {}".format(param, msg)
-                        msg = "DEPRECATION WARNING: {} {}".format(
-                            self.module_full_name, msg
-                        )
+                            msg = f"`{param}` {msg}"
+                        msg = "DEPRECATION WARNING: {} {}".format(self.module_full_name, msg)
                         self._py3_wrapper.log(msg)
 
                 if "rename" in deprecated:
@@ -685,7 +683,7 @@ class Module:
                         placeholder = item["placeholder"]
                         if "{}" in mod_config.get(param, ""):
                             mod_config[param] = mod_config[param].replace(
-                                "{}", "{%s}" % placeholder
+                                "{}", f"{{{placeholder}}}"
                             )
                             deprecation_log(item)
                 if "rename_placeholder" in deprecated:
@@ -698,9 +696,7 @@ class Module:
                             format_string = mod_config.get(format_param)
                             if not format_string:
                                 continue
-                            format = Formatter().update_placeholders(
-                                format_string, placeholders
-                            )
+                            format = Formatter().update_placeholders(format_string, placeholders)
                             mod_config[format_param] = format
 
                 if "update_placeholder_format" in deprecated:
@@ -726,10 +722,7 @@ class Module:
                         substitute = item["substitute"]
                         substitute_param = substitute["param"]
                         substitute_value = substitute["value"]
-                        if (
-                            mod_config.get(param) == value
-                            and substitute_param not in mod_config
-                        ):
+                        if mod_config.get(param) == value and substitute_param not in mod_config:
                             mod_config[substitute_param] = substitute_value
                             deprecation_log(item)
                 if "function" in deprecated:
@@ -807,7 +800,7 @@ class Module:
                 color = self.module_class.py3._get_color(urgent_background)
                 if not color:
                     err = "Invalid `urgent_background` attribute, should be "
-                    err += "a color. Got `{}`.".format(urgent_background)
+                    err += f"a color. Got `{urgent_background}`."
                     raise ValueError(err)
                 self.i3bar_gaps_urgent_options["background"] = color
 
@@ -817,7 +810,7 @@ class Module:
                 color = self.module_class.py3._get_color(urgent_foreground)
                 if not color:
                     err = "Invalid `urgent_foreground` attribute, should be "
-                    err += "a color. Got `{}`.".format(urgent_foreground)
+                    err += f"a color. Got `{urgent_foreground}`."
                     raise ValueError(err)
                 self.i3bar_gaps_urgent_options["foreground"] = color
 
@@ -827,7 +820,7 @@ class Module:
                 color = self.module_class.py3._get_color(urgent_border)
                 if not color:
                     err = "Invalid `urgent_border` attribute, should be a color. "
-                    err += "Got `{}`.".format(urgent_border)
+                    err += f"Got `{urgent_border}`."
                     raise ValueError(err)
                 self.i3bar_gaps_urgent_options["border"] = color
 
@@ -837,9 +830,9 @@ class Module:
                     if hasattr(param, "none_setting"):
                         param = 1
                     elif not isinstance(param, int):
-                        err = "Invalid `{}` attribute, ".format(name)
+                        err = f"Invalid `{name}` attribute, "
                         err += "should be an int. "
-                        err += "Got `{}`.".format(param)
+                        err += f"Got `{param}`."
                         raise TypeError(err)
                     self.i3bar_gaps_urgent_options[name[7:]] = param
 
@@ -848,8 +841,8 @@ class Module:
                 if method.startswith("_"):
                     continue
                 else:
-                    m_type = type(getattr(class_inst, method))
-                    if "method" in str(m_type):
+                    m_attr = inspect.getattr_static(class_inst, method)
+                    if isinstance(m_attr, FunctionType):
                         params_type = self._params_type(method, class_inst)
                         if method == "on_click":
                             self.click_events = params_type
@@ -861,7 +854,7 @@ class Module:
                             # the method_obj stores infos about each method
                             # of this module.
                             method_obj = {
-                                "cached_until": time(),
+                                "cached_until": time.monotonic(),
                                 "call_type": params_type,
                                 "instance": None,
                                 "last_output": {"name": method, "full_text": ""},
@@ -874,7 +867,7 @@ class Module:
         if self.config["debug"]:
             self._py3_wrapper.log(
                 'module "{}" click_events={} has_kill={} methods={}'.format(
-                    module, self.click_events, self.has_kill, self.methods.keys()
+                    module, self.click_events, self.has_kill, list(self.methods)
                 )
             )
 
@@ -917,7 +910,7 @@ class Module:
                 # nothing has happened so no need for refresh
                 self.prevent_refresh = True
         except Exception:
-            msg = "on_click event in `{}` failed".format(self.module_full_name)
+            msg = f"on_click event in `{self.module_full_name}` failed"
             self._py3_wrapper.report_exception(msg)
 
     @profile
@@ -931,17 +924,15 @@ class Module:
         if self._py3_wrapper.running:
             cache_time = None
             # execute each method of this module
-            for meth, obj in self.methods.items():
-                my_method = self.methods[meth]
-
+            for meth, my_method in self.methods.items():
                 # always check py3status is running
                 if not self._py3_wrapper.running:
                     break
 
                 # respect the cache set for this method
-                if time() < obj["cached_until"]:
-                    if not cache_time or obj["cached_until"] < cache_time:
-                        cache_time = obj["cached_until"]
+                if time.monotonic() < my_method["cached_until"]:
+                    if not cache_time or my_method["cached_until"] < cache_time:
+                        cache_time = my_method["cached_until"]
                     continue
 
                 try:
@@ -1018,9 +1009,7 @@ class Module:
 
                     # debug info
                     if self.config["debug"]:
-                        self._py3_wrapper.log(
-                            "method {} returned {} ".format(meth, result)
-                        )
+                        self._py3_wrapper.log(f"method {meth} returned {result} ")
                     # module working correctly so ensure module works as
                     # expected
                     self.allow_config_clicks = True
@@ -1037,9 +1026,9 @@ class Module:
                         if e.timeout is Py3.CACHE_FOREVER:
                             cache_time = Py3.CACHE_FOREVER
                         else:
-                            cache_time = time() + e.timeout
+                            cache_time = time.monotonic() + e.timeout
                     else:
-                        cache_time = time() + getattr(
+                        cache_time = time.monotonic() + getattr(
                             self.module_class,
                             "cache_timeout",
                             self.config["cache_timeout"],
@@ -1052,20 +1041,21 @@ class Module:
                         self._py3_wrapper.report_exception(msg, notify_user=False)
                     # added error
                     self.runtime_error(str(e) or e.__class__.__name__, meth)
-                    cache_time = time() + getattr(
+                    cache_time = time.monotonic() + getattr(
                         self.module_class, "cache_timeout", self.config["cache_timeout"]
                     )
 
             if cache_time is None:
-                cache_time = time() + self.config["cache_timeout"]
+                cache_time = time.monotonic() + self.config["cache_timeout"]
             self.cache_time = cache_time
             # new style modules can signal they want to cache forever
             if cache_time == Py3.CACHE_FOREVER:
+                self._py3_wrapper.clear_timeout_due(self)
                 return
             # don't be hasty mate
             # set timeout to do update next time one is needed
             if not cache_time:
-                cache_time = time() + self.config["minimum_interval"]
+                cache_time = time.monotonic() + self.config["minimum_interval"]
 
             self._py3_wrapper.timeout_queue_add(self, cache_time)
 
