@@ -99,10 +99,10 @@ SAMPLE OUTPUT
 """
 
 from errno import ENOENT
-from os.path import expanduser
-import requests
+from pathlib import Path
 from string import Formatter
 
+import requests
 
 COIN_PORTS = {"bitcoin": 8332, "dogecoin": 22555, "litecoin": 9332}
 
@@ -110,8 +110,7 @@ REQUEST = {"method": "getbalance"}
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     cache_timeout = 30
@@ -144,7 +143,7 @@ class Py3status:
 
     def _get_daemon_config_value(self, coin, key):
         try:
-            with open(expanduser("~/.{0}/{0}.conf".format(coin))) as cfg:
+            with (Path.home() / f".{coin}" / coin).open() as cfg:
                 for line in cfg.readlines():
                     line = line.strip()
                     if line.startswith("#"):
@@ -159,13 +158,13 @@ class Py3status:
 
     def _get_credentials(self, coin):
         if coin not in self._credential_cache:
-            username = getattr(self, "{}_username".format(coin), None)
+            username = getattr(self, f"{coin}_username", None)
             if username is None:
                 username = getattr(self, "username", None)
             if username is None:
                 username = self._get_daemon_config_value(coin, "rpcuser")
 
-            password = getattr(self, "{}_password".format(coin), None)
+            password = getattr(self, f"{coin}_password", None)
             if password is None:
                 password = getattr(self, "password", None)
             if password is None:
